package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBaseInspectStandard;

/**
 * 巡检标准信息Mapper接口
 * 
 * @author Open Platform
 * @date 2024-01-17
 */
public interface DmsBaseInspectStandardMapper 
{
    /**
     * 查询巡检标准信息
     * 
     * @param inspectStandardId 巡检标准信息主键
     * @return 巡检标准信息
     */
    public DmsBaseInspectStandard selectDmsBaseInspectStandardByInspectStandardId(Long inspectStandardId);

    /**
     * 查询巡检标准信息列表
     * 
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 巡检标准信息集合
     */
    public List<DmsBaseInspectStandard> selectDmsBaseInspectStandardList(DmsBaseInspectStandard dmsBaseInspectStandard);

    /**
     * 新增巡检标准信息
     * 
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 结果
     */
    public int insertDmsBaseInspectStandard(DmsBaseInspectStandard dmsBaseInspectStandard);

    /**
     * 修改巡检标准信息
     * 
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 结果
     */
    public int updateDmsBaseInspectStandard(DmsBaseInspectStandard dmsBaseInspectStandard);

    /**
     * 删除巡检标准信息
     * 
     * @param inspectStandardId 巡检标准信息主键
     * @return 结果
     */
    public int deleteDmsBaseInspectStandardByInspectStandardId(Long inspectStandardId);

    /**
     * 批量删除巡检标准信息
     * 
     * @param inspectStandardIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseInspectStandardByInspectStandardIds(Long[] inspectStandardIds);
}
