package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseInspectStandard;
import com.hw.dms.service.IDmsBaseInspectStandardService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 巡检标准信息Controller
 * 
 * @author Open Platform
 * @date 2024-01-17
 */
@RestController
@RequestMapping("/dmsBaseInspectStandard")
public class DmsBaseInspectStandardController extends BaseController
{
    @Autowired
    private IDmsBaseInspectStandardService dmsBaseInspectStandardService;

    /**
     * 查询巡检标准信息列表
     */
    @RequiresPermissions("dms:dmsBaseInspectStandard:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        startPage();
        List<DmsBaseInspectStandard> list = dmsBaseInspectStandardService.selectDmsBaseInspectStandardList(dmsBaseInspectStandard);
        return getDataTable(list);
    }

    /**
     * 导出巡检标准信息列表
     */
    @RequiresPermissions("dms:dmsBaseInspectStandard:export")
    @Log(title = "巡检标准信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        List<DmsBaseInspectStandard> list = dmsBaseInspectStandardService.selectDmsBaseInspectStandardList(dmsBaseInspectStandard);
        ExcelUtil<DmsBaseInspectStandard> util = new ExcelUtil<DmsBaseInspectStandard>(DmsBaseInspectStandard.class);
        util.exportExcel(response, list, "巡检标准信息数据");
    }

    /**
     * 获取巡检标准信息详细信息
     */
    @RequiresPermissions("dms:dmsBaseInspectStandard:query")
    @GetMapping(value = "/{inspectStandardId}")
    public AjaxResult getInfo(@PathVariable("inspectStandardId") Long inspectStandardId)
    {
        return success(dmsBaseInspectStandardService.selectDmsBaseInspectStandardByInspectStandardId(inspectStandardId));
    }

    /**
     * 新增巡检标准信息
     */
    @RequiresPermissions("dms:dmsBaseInspectStandard:add")
    @Log(title = "巡检标准信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        return toAjax(dmsBaseInspectStandardService.insertDmsBaseInspectStandard(dmsBaseInspectStandard));
    }

    /**
     * 修改巡检标准信息
     */
    @RequiresPermissions("dms:dmsBaseInspectStandard:edit")
    @Log(title = "巡检标准信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        return toAjax(dmsBaseInspectStandardService.updateDmsBaseInspectStandard(dmsBaseInspectStandard));
    }

    /**
     * 删除巡检标准信息
     */
    @RequiresPermissions("dms:dmsBaseInspectStandard:remove")
    @Log(title = "巡检标准信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{inspectStandardIds}")
    public AjaxResult remove(@PathVariable Long[] inspectStandardIds)
    {
        return toAjax(dmsBaseInspectStandardService.deleteDmsBaseInspectStandardByInspectStandardIds(inspectStandardIds));
    }
}
